@@ -4,9 +4,9 @@
 #' @param ...  ignored
 #' 
 #' @aliases
-#' repr_markdown.logical repr_markdown.integer repr_markdown.complex repr_markdown.numeric repr_markdown.factor repr_markdown.character repr_markdown.Date
-#'    repr_latex.logical    repr_latex.integer    repr_latex.complex    repr_latex.numeric    repr_latex.factor    repr_latex.character    repr_latex.Date
-#'     repr_html.logical     repr_html.integer     repr_html.complex     repr_html.numeric     repr_html.factor     repr_html.character     repr_html.Date
+#' repr_markdown.logical repr_markdown.integer repr_markdown.complex repr_markdown.numeric  repr_markdown.character repr_markdown.Date
+#'    repr_latex.logical    repr_latex.integer    repr_latex.complex    repr_latex.numeric     repr_latex.character    repr_latex.Date
+#'     repr_html.logical     repr_html.integer     repr_html.complex     repr_html.numeric      repr_html.character     repr_html.Date
 #' @name repr_*.vector
 #' @include repr_list.r
 #' @include utils.r
@@ -30,7 +30,8 @@ repr_vector_generic <- function(
 		nms <- escape_fun(nms)
 	
 	qt <- is.character(vec) && getOption('repr.vector.quote')
-	char_vec <- escape_fun(if (qt) r_quote(vec) else as.character(vec))
+	# excape_fun is output format specific, encodeString ensures that non-printables come out as \-escapes
+	char_vec <- escape_fun(encodeString(as.character(vec), quote = if (qt) "'" else ''))
 	
 	if (!is.null(individual_wrap)) {
 		char_vec <- sprintf(individual_wrap, char_vec, char_vec)
@@ -94,10 +95,6 @@ repr_html.complex <- repr_html.logical
 #' @export
 repr_html.numeric <- repr_html.logical
 
-#' @name repr_*.vector
-#' @export
-repr_html.factor <- repr_html.logical
-
 #' @name repr_*.vector
 #' @export
 repr_html.character <- repr_html.logical
@@ -137,10 +134,6 @@ repr_markdown.complex <- repr_markdown.logical
 #' @export
 repr_markdown.numeric <- repr_markdown.logical
 
-#' @name repr_*.vector
-#' @export
-repr_markdown.factor <- repr_markdown.logical
-
 #' @name repr_*.vector
 #' @export
 repr_markdown.character <- repr_markdown.logical
@@ -180,10 +173,6 @@ repr_latex.complex <- repr_latex.logical
 #' @export
 repr_latex.numeric <- repr_latex.logical
 
-#' @name repr_*.vector
-#' @export
-repr_latex.factor <- repr_latex.logical
-
 #' @name repr_*.vector
 #' @export
 repr_latex.character <- repr_latex.logical
